@@ -1,4 +1,4 @@
-// $Id: DispBox.h,v 1.20 1998/05/06 18:37:25 zeller Exp $
+// $Id: DispBox.h,v 1.31 1999/08/19 11:27:21 andreas Exp $
 // Display boxes
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -23,8 +23,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_DispBox_h
 #define _DDD_DispBox_h
@@ -40,6 +40,7 @@
 #include "strclass.h"
 #include "Box.h"
 #include "VSLLib.h"
+#include "VSLArgList.h"
 #include "DispValue.h"
 #include "assert.h"
 
@@ -47,12 +48,20 @@
 
 class DispBox {
 private:
-    Box* mybox;
-    Box* title_box;
+    Box *mybox;
+    Box *title_box;
 
-    DispBox(const DispBox&): mybox(0), title_box(0) { assert(0); }
+protected:
+    DispBox(const DispBox &node)
+	: mybox(node.mybox ? node.mybox->dup() : 0),
+	  title_box(node.title_box ? node.title_box->dup() : 0)
+    {}
+
+private:
     DispBox& operator = (const DispBox&) { assert(0); return *this; }
 
+    static bool is_numeric(const DispValue *dv, const DispValue *parent);
+
 public:
     // Must be initialized from outside!
     static string  vsllib_name;
@@ -68,20 +77,31 @@ public:
     // Initialize VSL library, using BACKGROUND as work proc
     static void init_vsllib(void (*background)() = 0);
 
-    // Create a new box; if DV == 0, create a `disabled' box
-    DispBox (int disp_nr,
-	     const string& name,
-	     const DispValue* dv = 0);
+    // Create a new box.  If DV == 0, create a disabled box.
+    DispBox (int disp_nr, const string& title, 
+	     const DispValue *dv = 0, const DispValue *parent = 0);
 
     ~DispBox ();
 
-    Box* box () const { return mybox; }
+    Box *box () const { return mybox; }
 
-    // Set new value to DV; if DV == 0, create a `disabled' box
-    void set_value (const DispValue* dv = 0);
+    DispBox *dup() const { return new DispBox(*this); }
+
+    // Set new value to DV.  If DV == 0, make it disabled.
+    void set_value (const DispValue *dv, const DispValue *parent = 0);
+
+    // Set title to NAME; if NAME == "", disable it
+    void set_title(int disp_nr, string name);
+
+    bool have_title() const { return title_box != 0; }
 
 private:
-    Box*   create_value_box (const DispValue* dv, int member_name_width = 0);
+    Box *create_value_box(const DispValue *dv,
+			  const DispValue *parent,
+			  int member_name_width = 0);
+
+    Box *_create_value_box(const DispValue *dv,
+			   const DispValue *parent);
 
     static VSLLib dummylib;
     static VSLLib *vsllib_ptr;
@@ -96,21 +116,27 @@ private:
 
 protected:
     // Evaluation functions
-    static Box *dup(const string& func_name, const Box *box);
-    static Box *eval(const string& func_name, ListBox *arg)
+    static Box *check(const string& func_name, const Box *box);
+
+    static void shorten_title(string& title);
+
+public:
+    static Box *eval(const string& func_name, const VSLArgList& args)
     {
-	return dup(func_name, vsllib()->eval(func_name, arg));
+	return check(func_name, vsllib()->eval(func_name, args.list()));
     }
     static Box *eval(const string& func_name, VSLArg args[])
     {
-	return dup(func_name, vsllib()->eval(func_name, args));
+	return check(func_name, vsllib()->eval(func_name, args));
     }
     static Box *eval(const string& func_name, 
 		     VSLArg arg1 = (Box *)0,
 		     VSLArg arg2 = (Box *)0,
-		     VSLArg arg3 = (Box *)0)
+		     VSLArg arg3 = (Box *)0,
+		     VSLArg arg4 = (Box *)0)
     {
-	return dup(func_name, vsllib()->eval(func_name, arg1, arg2, arg3));
+	return check(func_name, 
+		     vsllib()->eval(func_name, arg1, arg2, arg3, arg4));
     }
 };
 
