@@ -1,8 +1,10 @@
-// $Id: GDBAgent.h,v 1.107.4.1 1998/12/16 12:55:46 zeller Exp $
+// $Id: GDBAgent.h,v 1.111 2000/01/07 10:58:18 andreas Exp $
 // Communicate with separate GDB process
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
-// Written by Dorothea Luetkehaus <luetke@ips.cs.tu-bs.de>.
+// Copyright (C) 2000 Universitaet Passau, Germany.
+// Written by Dorothea Luetkehaus <luetke@ips.cs.tu-bs.de>
+// and Andreas Zeller <zeller@gnu.org>.
 // 
 // This file is part of DDD.
 // 
@@ -23,8 +25,8 @@
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 //-----------------------------------------------------------------------------
 // A GDBAgent creates a connection to an inferior GDB via a TTYAgent.
@@ -525,7 +527,7 @@ public:
     bool has_temporary_breakpoints() const
     {
 	return type() == GDB || type() == XDB || type() == PYDB || 
-	       has_when_command();
+	       has_when_command() || type() == PERL;
     }
 
     // True if debugger supports breakpoint conditions
@@ -535,6 +537,13 @@ public:
 	       type() == DBX || type() == PYDB || type() == PERL;
     }
 
+    // True if debugger supports breakpoint commands
+    bool has_breakpoint_commands() const
+    {
+	return type() == GDB || type() == XDB || 
+	       has_when_command() || type() == PERL;
+    }
+
     // True if debugger has typed pointers, as in `(TYPE)0x0'
     bool has_typed_pointers() const
     {
@@ -708,6 +717,10 @@ public:
 	return write(data.chars(), data.length());
     }
 
+    // Write a command (not debuggee interaction or control characters)
+    int write_cmd(const string& cmd);
+
+    // True if ANSWER ends in a prompt
     bool ends_with_prompt(const string& answer);
     bool ends_with_secondary_prompt(const string& answer);
 
