@@ -1,9 +1,9 @@
 #!/usr/local/bin/perl
-# $Id: perltest.pl,v 1.6 1998/10/27 09:14:44 zeller Exp $
+# $Id: perltest.pl,v 1.8 1999/08/19 11:28:46 andreas Exp $
 # Perl test
 
 # Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
-# Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+# Written by Andreas Zeller <zeller@gnu.org>.
 # 
 # This file is part of DDD.
 # 
@@ -24,8 +24,8 @@
 # 
 # DDD is the data display debugger.
 # For details, see the DDD World-Wide-Web page, 
-# `http://www.cs.tu-bs.de/softech/ddd/',
-# or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+# `http://www.gnu.org/software/ddd/',
+# or send a mail to the DDD developers <ddd@gnu.org>.
 
 $foo = 42;
 
@@ -73,6 +73,12 @@ $g = newprint("Greetings");
 &$g("earthlings");
 
 
+# I/O
+print "What's your name? ";
+chop($name = <>);
+print "Hello, $name!\n";
+
+
 # Globs
 $fh = *STDOUT;
 
