@@ -1,30 +1,30 @@
-// $Id: post.h,v 1.7 1997/10/03 10:41:13 zeller Exp $ -*- C++ -*-
+// $Id: post.h,v 1.10 1999/08/19 11:28:47 andreas Exp $ -*- C++ -*-
 //
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
-// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
+// Written by Andreas Zeller <zeller@gnu.org>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
 // DDD is the data display debugger.
 // For details, see the DDD World-Wide-Web page, 
-// `http://www.cs.tu-bs.de/softech/ddd/',
-// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.
+// `http://www.gnu.org/software/ddd/',
+// or send a mail to the DDD developers <ddd@gnu.org>.
 
 #ifndef _DDD_post_h
 #define _DDD_post_h
@@ -34,6 +34,7 @@
 #endif
 
 #include "strclass.h"
+#include "bool.h"
 #include <X11/Intrinsic.h>
 
 // Error handling
@@ -44,7 +45,8 @@
 // command is used.  Each function returns the created, managed, and
 // raised widget, or 0 if no widget was shown.
 extern Widget post_gdb_busy(Widget origin = 0);
-extern Widget post_gdb_message(string text, Widget origin = 0);
+extern Widget post_gdb_message(string text, bool prompt = true, 
+			       Widget origin = 0);
 extern Widget post_gdb_yn(string text, Widget origin = 0);
 extern Widget post_gdb_died(string reason, int gdb_status, Widget origin = 0);
 extern Widget post_error(string text, String name = 0, Widget origin = 0);
