@@ -1,4 +1,4 @@
-// $Id: strclass.h,v 1.31 1998/11/26 09:31:22 zeller Exp $
+// $Id: strclass.h,v 1.32 1999/10/20 11:06:43 andreas Exp $
 // A string class (based on `String' from GNU libg++-2.3)
 
 // This may look like C code, but it is really -*- C++ -*-
@@ -2155,20 +2155,20 @@ string_COMPARE_ALL(char, const subString&)
 #undef string_COMPARE_ALL
 
 // A helper needed by at, before, etc.
-inline subString string::_substr(int first, int l)
+inline subString string::_substr(int first, int len)
 {
-    if (first < 0 || (unsigned)(first + l) > length())
+    if (first < 0 || len <= 0 || (unsigned)(first + len) > length())
 	return subString(_nilstring, 0, 0);
     else 
-	return subString(*this, first, l);
+	return subString(*this, first, len);
 }
 
-inline const subString string::_substr(int first, int l) const
+inline const subString string::_substr(int first, int len) const
 {
-    if (first < 0 || (unsigned)(first + l) > length())
+    if (first < 0 || len <= 0 || (unsigned)(first + len) > length())
 	return subString(_nilstring, 0, 0);
     else 
-	return subString(*this, first, l);
+	return subString(*this, first, len);
 }
 
 #endif // _ICE_strclass_h
